require 'studio_game/game'
module StudioGame
  describe Game do

    before do
      @game = Game.new("Knuckleheads")

      @initial_health = 100
      @player = Player.new("moe", @initial_health)

      @game.add_player(@player)
      @player1 = Player.new("moe", 100)
      @player2 = Player.new("larry", 200)
      @player3 = Player.new("curly", 300)
      @players = [@player1, @player2, @player3]
    end

    it "has a title" do
      @game.title.should == "Knuckleheads"
    end

    it "w00ts the player if a high number is rolled" do
      Die.any_instance.stub(:roll).and_return(5)

      @game.play(3)

      @player.health.should == @initial_health + 15 * 3
    end

    it "skips the player if a medium number is rolled" do
      Die.any_instance.stub(:roll).and_return(3)

      @game.play(3)

      @player.health.should == @initial_health
    end

    it "blams the player if a low number is rolled" do
      Die.any_instance.stub(:roll).and_return(1)

      @game.play(3)

      @player.health.should == @initial_health - 10 * 3
    end

    it "sorts by increasing order" do
      @players.sort.should == [@player3, @player2, @player1]
    end

    it "assigns a treasure for points during a player's turn" do
      game = Game.new("Knuckleheads")
      player = Player.new("moe")

      game.add_player(player)

      game.play(1)

      player.points.should_not be_zero

      # or use alternate expectation syntax:
      # expect(player.points).not_to be_zero
    end

  end
end
